Align SSL_set_{min,max}_version with upstream.

Upstream added these functions after we did but decided to change the
names slightly. I'm not sure why they wanted to add the "proto" in
there, but align with them nonetheless so the ecosystem only has one set
of these functions.

BUG=90

Change-Id: Ia9863c58c9734374092051f02952b112806040cc
Reviewed-on: https://boringssl-review.googlesource.com/11123
Reviewed-by: David Benjamin <davidben@google.com>
Commit-Queue: David Benjamin <davidben@google.com>
CQ-Verified: CQ bot account: commit-bot@chromium.org <commit-bot@chromium.org>
diff --git a/include/openssl/ssl.h b/include/openssl/ssl.h
index aee297c..8f097fe 100644
--- a/include/openssl/ssl.h
+++ b/include/openssl/ssl.h
@@ -564,21 +564,21 @@
 
 #define TLS1_3_DRAFT_VERSION 14
 
 /* SSL_CTX_set_min_version sets the minimum protocol version for |ctx| to
  * |version|. It returns one on success and zero if |version| is invalid. */
-OPENSSL_EXPORT int SSL_CTX_set_min_version(SSL_CTX *ctx, uint16_t version);
+OPENSSL_EXPORT int SSL_CTX_set_min_proto_version(SSL_CTX *ctx, uint16_t version);
 
 /* SSL_CTX_set_max_version sets the maximum protocol version for |ctx| to
  * |version|. It returns one on success and zero if |version| is invalid. */
-OPENSSL_EXPORT int SSL_CTX_set_max_version(SSL_CTX *ctx, uint16_t version);
+OPENSSL_EXPORT int SSL_CTX_set_max_proto_version(SSL_CTX *ctx, uint16_t version);
 
 /* SSL_set_min_version sets the minimum protocol version for |ssl| to
  * |version|. It returns one on success and zero if |version| is invalid. */
-OPENSSL_EXPORT int SSL_set_min_version(SSL *ssl, uint16_t version);
+OPENSSL_EXPORT int SSL_set_min_proto_version(SSL *ssl, uint16_t version);
 
 /* SSL_set_max_version sets the maximum protocol version for |ssl| to
  * |version|. It returns one on success and zero if |version| is invalid. */
-OPENSSL_EXPORT int SSL_set_max_version(SSL *ssl, uint16_t version);
+OPENSSL_EXPORT int SSL_set_max_proto_version(SSL *ssl, uint16_t version);
 
 /* SSL_version returns the TLS or DTLS protocol version used by |ssl|, which is
  * one of the |*_VERSION| values. (E.g. |TLS1_2_VERSION|.) Before the version
@@ -608,7 +608,8 @@
 #define SSL_OP_DISABLE_NPN 0x00800000L
 
 /* The following flags toggle individual protocol versions. This is deprecated.
  * Use |SSL_CTX_set_min_version| and |SSL_CTX_set_max_version| instead. */
 #define SSL_OP_NO_SSLv3 0x02000000L
 #define SSL_OP_NO_TLSv1 0x04000000L
 #define SSL_OP_NO_TLSv1_2 0x08000000L
@@ -3134,8 +3135,9 @@
 OPENSSL_EXPORT const SSL_METHOD *SSLv23_method(void);
 
 /* These version-specific methods behave exactly like |TLS_method| and
  * |DTLS_method| except they also call |SSL_CTX_set_min_version| and
  * |SSL_CTX_set_max_version| to lock connections to that protocol version. */
 OPENSSL_EXPORT const SSL_METHOD *SSLv3_method(void);
 OPENSSL_EXPORT const SSL_METHOD *TLSv1_method(void);
 OPENSSL_EXPORT const SSL_METHOD *TLSv1_1_method(void);
@@ -3564,6 +3566,18 @@
  * netty-tcnative. */
 OPENSSL_EXPORT void SSL_set_verify_result(SSL *ssl, long result);
 
+/* SSL_CTX_set_min_version calls |SSL_CTX_set_min_proto_version|. */
+OPENSSL_EXPORT int SSL_CTX_set_min_version(SSL_CTX *ctx, uint16_t version);
+
+/* SSL_CTX_set_max_version calls |SSL_CTX_set_max_proto_version|. */
+OPENSSL_EXPORT int SSL_CTX_set_max_version(SSL_CTX *ctx, uint16_t version);
+
+/* SSL_set_min_version calls |SSL_set_min_proto_version|. */
+OPENSSL_EXPORT int SSL_set_min_version(SSL *ssl, uint16_t version);
+
+/* SSL_set_max_version calls |SSL_set_max_proto_version|. */
+OPENSSL_EXPORT int SSL_set_max_version(SSL *ssl, uint16_t version);
+
 
 /* Private structures.
  *
@@ -564,21 +564,21 @@
 #define TLS1_3_DRAFT_VERSION 14
 
-/* SSL_CTX_set_min_version sets the minimum protocol version for |ctx| to
+/* SSL_CTX_set_min_proto_version sets the minimum protocol version for |ctx| to
  * |version|. It returns one on success and zero if |version| is invalid. */
@@ -564,21 +564,21 @@
 
-/* SSL_CTX_set_max_version sets the maximum protocol version for |ctx| to
+/* SSL_CTX_set_max_proto_version sets the maximum protocol version for |ctx| to
  * |version|. It returns one on success and zero if |version| is invalid. */
@@ -564,21 +564,21 @@
 
-/* SSL_set_min_version sets the minimum protocol version for |ssl| to
+/* SSL_set_min_proto_version sets the minimum protocol version for |ssl| to
  * |version|. It returns one on success and zero if |version| is invalid. */
@@ -564,21 +564,21 @@
 
-/* SSL_set_max_version sets the maximum protocol version for |ssl| to
+/* SSL_set_max_proto_version sets the maximum protocol version for |ssl| to
  * |version|. It returns one on success and zero if |version| is invalid. */
@@ -608,7 +608,8 @@
 
 /* The following flags toggle individual protocol versions. This is deprecated.
- * Use |SSL_CTX_set_min_version| and |SSL_CTX_set_max_version| instead. */
+ * Use |SSL_CTX_set_min_proto_version| and |SSL_CTX_set_max_proto_version|
+ * instead. */
 #define SSL_OP_NO_SSLv3 0x02000000L
 #define SSL_OP_NO_TLSv1 0x04000000L
@@ -3134,8 +3135,9 @@
 
 /* These version-specific methods behave exactly like |TLS_method| and
- * |DTLS_method| except they also call |SSL_CTX_set_min_version| and
- * |SSL_CTX_set_max_version| to lock connections to that protocol version. */
+ * |DTLS_method| except they also call |SSL_CTX_set_min_proto_version| and
+ * |SSL_CTX_set_max_proto_version| to lock connections to that protocol
+ * version. */
 OPENSSL_EXPORT const SSL_METHOD *SSLv3_method(void);
 OPENSSL_EXPORT const SSL_METHOD *TLSv1_method(void);